import { Location, LocationDescriptorObject, LocationState, Path } from 'history';
import { match as Match } from 'react-router';
export declare const LOCATION_CHANGE = "@@router/LOCATION_CHANGE";
export declare const CALL_HISTORY_METHOD = "@@router/CALL_HISTORY_METHOD";
export interface LocationChangeAction {
    type: typeof LOCATION_CHANGE;
    payload: {
        location: Location;
        match?: Match<any>;
    };
}
export declare type UpdateLocationMethod = 'push' | 'replace' | 'go' | 'goBack' | 'goForward';
export interface RouterAction<Method = UpdateLocationMethod, Args = any[]> {
    type: typeof CALL_HISTORY_METHOD;
    payload: {
        method: Method;
        args: Args;
    };
}
export interface UpdateLocationActionCreator<Method extends 'push' | 'replace'> {
    (path: Path): RouterAction<Method, [Path]>;
    (path: Path, state: LocationState): RouterAction<Method, [Path, LocationState]>;
    (location: LocationDescriptorObject): RouterAction<Method, [LocationDescriptorObject]>;
}
export declare function locationChange(location: Location, match?: Match<any>): LocationChangeAction;
export declare const push: UpdateLocationActionCreator<"push">;
export declare const replace: UpdateLocationActionCreator<"replace">;
export declare const go: (n: number) => RouterAction<"go", [number]>;
export declare const goBack: () => RouterAction<"goBack", undefined[]>;
export declare const goForward: () => RouterAction<"goForward", undefined[]>;
export declare const routerActions: {
    push: UpdateLocationActionCreator<"push">;
    replace: UpdateLocationActionCreator<"replace">;
    go: (n: number) => RouterAction<"go", [number]>;
    goBack: () => RouterAction<"goBack", undefined[]>;
    goForward: () => RouterAction<"goForward", undefined[]>;
};
